@@ -23,11 +23,11 @@ OC.L10N.register(
     "Delete" : "Borrar",
     "New calendar" : "Nuevo calendario",
     "Export" : "Exportar",
+    "Empty trash bin" : "Vacíar la papelera",
     "Name" : "Nombre",
     "Deleted" : "Borrado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
-    "Empty trash bin" : "Vacíar la papelera",
     "Deck" : "Deck",
     "Hidden" : "Oculto",
     "Share link" : "Compartir enlace",
@@ -37,10 +37,11 @@ OC.L10N.register(
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
-    "or" : "o",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
+    "or" : "o",
     "Show week numbers" : "Mostrar número de semana",
+    "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
     "to" : "para",
@@ -52,12 +53,14 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
-    "Delete file" : "Borrar archivo",
+    "hours" : "horas",
+    "days" : "días",
+    "weeks" : "semanas",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Delete file" : "Borrar archivo",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
